@@ -48,11 +48,12 @@ class VideoVariable(Variable):
     driver_names = OrderedDict([
         ('default', _("X.Org Server auto detection")),
         ('radeon', _("AMD Radeon (radeon)")),
+        ('amdgpu', _("AMD AMDGPU (amdgpu)")),
         ('fglrx', _("AMD Catalyst (fglrx)")),
-        ('intel', _("Intel Graphic Driver (intel)")),
-        ('nouveau', _("NVidia open-source driver (nouveau)")),
-        ('nvidia', _("Nvidia Graphic Driver (nvidia)")),
-        ('vesa', _("Generic Vesa (vesa)")),
+        ('intel', _("Intel (intel)")),
+        ('nouveau', _("Nvidia Nouveau (nouveau)")),
+        ('nvidia', _("Nvidia Graphics Driver (nvidia)")),
+        ('vesa', _("Generic VESA (vesa)")),
     ])
 
     def uncompatible(self):
@@ -131,7 +132,7 @@ class VariableOsInstallX11VideoAvailable(VideoVariable):
     """
     type = "list"
     # supported = ["nvidia", "fglrx", "amdgpu", "nouveau", "intel", "radeon"]
-    supported = ["nvidia", "fglrx", "nouveau", "intel", "radeon"]
+    supported = ["nvidia", "fglrx", "amdgpu", "nouveau", "intel", "radeon"]
 
     def get(self):
         image = self.Get('cl_image')
@@ -157,7 +158,7 @@ class VariableOsX11KmsVideoDrv(ReadonlyVariable):
     Список KMS драйверов
     """
     type = "list"
-    value = ["radeon", "intel", "nouveau"]  # , "amdgpu"]
+    value = ["radeon", "intel", "nouveau", "amdgpu"]
 
 
 class VariableOsInstallX11VideoDrv(VideoVariable):
